Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit d2fd1f5


[ROCm/hip commit: fbaf729f88]
This commit is contained in:
Alex Voicu
2017-11-29 21:36:29 +00:00
orang tua c58a083e96
melakukan fcc42f035e
62 mengubah file dengan 152 tambahan dan 152 penghapusan
+2 -2
Melihat File
@@ -1307,9 +1307,9 @@ namespace
__global__
void hip_fill_n(RandomAccessIterator f, N n, T value)
{
const uint32_t grid_dim = gridDim.x * blockDim.x;
const uint32_t grid_dim = hipGridDim_x * hipBlockDim_x;
size_t idx = blockIdx.x * block_dim + threadIdx.x;
size_t idx = hipBlockIdx_x * block_dim + hipThreadIdx_x;
while (idx < n) {
__builtin_memcpy(
reinterpret_cast<void*>(&f[idx]),